from setuptools import setup

setup(name='distributions_2020',
      version='1.0',
      description='Gaussian and Binomial distributions_2020',
      packages=['distributions_2020'],
      author = 'Ajmal Muhammed',
      author_email = 'ajmalmohammedn@gmail.com',
      zip_safe=False)